import fs from 'fs';
import path from 'path';

/**
 * Get all subdirectories in a passed-in directory.
 * @param  {string} srcpath The path of the directory to search.
 * @return {array}         The subdirectories.
 */
function getDirectories(srcpath) {
  return fs
    .readdirSync(srcpath)
    .filter(file => fs.statSync(path.join(srcpath, file)).isDirectory());
}

/**
 * Run the script.
 */
export default function copyIndexPHPFilesFromNodeModules() {
  const directories = getDirectories(
    path.normalize(`${process.env.PWD}/node_modules`),
  );

  if (!directories) {
    return;
  }

  directories.forEach((directory) => {
    const PHPfilename = path.normalize(
      `${process.env.PWD}/node_modules/${directory}/index.php`,
    );

    if (fs.existsSync(PHPfilename)) {
      fs
        .createReadStream(PHPfilename)
        .pipe(
          fs.createWriteStream(
            `${process.env.PWD}/wp-autoload/from-node/${directory}.php`,
          ),
        );
    }
  });
}
